@@ -1,4 +1,4 @@
-from ungreat_matching import ungreat_match, num_match_max, num_match_min
+from ungreat_matching import ungreat_match
 
 
 test_data = [['python','Python'],
